@@ -1,12 +1,12 @@
 package OpenInteract::Handler::SystemBoxes;
 
-# $Id: SystemBoxes.pm,v 1.10 2002/01/02 02:43:54 lachoy Exp $
+# $Id: SystemBoxes.pm,v 1.11 2002/01/23 17:23:14 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 
 @OpenInteract::Handler::SystemBoxes::ISA     = qw();
-$OpenInteract::Handler::SystemBoxes::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::SystemBoxes::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::SystemBoxes::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::SystemBoxes::default_method    = 'handler';
@@ -126,6 +126,10 @@ sub templates_used {
         }
         else {
             ( $package, $name ) = $R->site_template->parse_name( $template );
+            if ( $package and ! $name ) {
+                $name    = $package;
+                $package = '(site)';
+            }
             $full_name = $template;
         }
         next if ( $tmpl_used{ $package }{ $name } );
